@@ -243,7 +243,7 @@ void Godville::readJson(QNetworkReply* list)
           .arg(list->error()));
         ok = false;
         if (!settings.contains("data"))
-            QApplication::quit();
+            options();
     }
     list->deleteLater();
     list = NULL;
@@ -276,86 +276,86 @@ void Godville::updateData()
     levelLabel->setText(data->value("level").toString());
     if (data->contains("diary_last"))
     {
-    inventoryLabel->setText(tr("%1/%2")
-      .arg(data->value("inventory_num").toString())
-      .arg(data->value("inventory_max_num").toString()));
-    healthLabel->setText(tr("%1/%2")
-      .arg(data->value("health").toString())
-      .arg(data->value("max_health").toString()));
-    experienceBar->setValue(data->value("exp_progress").toInt());
-    inventoryBar->setMaximum(data->value("inventory_max_num").toInt());
-    inventoryBar->setValue(data->value("inventory_num").toInt());
-    healthBar->setMaximum(data->value("max_health").toInt());
-    healthBar->setValue(data->value("health").toInt());
-    if (healthBar->value()<healthBar->maximum()*0.3)
-        setBarStyle(healthBar, "eb0000");
-    else if (healthBar->value()>healthBar->maximum()*0.7)
-        setBarStyle(healthBar, "008000");
-    else
-        setBarStyle(healthBar, "f6f600");
-    questBar->setValue(data->value("quest_progress").toInt());
-    diaryLabel->setText(data->value("diary_last").toString());
-    energyLabel->setText(data->value("godpower").toString() + "%");
-    energyBar->setValue(data->value("godpower").toInt());
-    if (data->value("town_name").toString()=="")
-    {
-        diLabel->setText(tr("Столбов от столицы"));
-        distanceLabel->setText(tr("%1 шт.")
-          .arg(data->value("distance").toString()));
-    }
-    else
-    {
-        diLabel->setText(tr("Город"));
-        distanceLabel->setText(data->value("town_name").toString());
-    }
-
-    QMap<QString, QVariant> inventory = data->value("inventory").toMap();
-    int n = data->value("inventory_num").toInt();
-    while (inventoryList.size()<n)
-    {
-        QLabel* lbl = new QLabel;
-        inventoryList.append(lbl);
-        inventoryVLayout->addWidget(lbl);
-        lbl->setWordWrap(true);
-    }
-    QMapIterator<QString, QVariant> i(inventory);
-    while (i.hasNext())
-    {
-        i.next();
-        QVariantMap item = i.value().toMap();
-        int j = item.value("pos").toInt();
-        QString text = i.key();
-        if (item.value("cnt").toInt()>1)
+        inventoryLabel->setText(tr("%1/%2")
+          .arg(data->value("inventory_num").toString())
+          .arg(data->value("inventory_max_num").toString()));
+        healthLabel->setText(tr("%1/%2")
+          .arg(data->value("health").toString())
+          .arg(data->value("max_health").toString()));
+        experienceBar->setValue(data->value("exp_progress").toInt());
+        inventoryBar->setMaximum(data->value("inventory_max_num").toInt());
+        inventoryBar->setValue(data->value("inventory_num").toInt());
+        healthBar->setMaximum(data->value("max_health").toInt());
+        healthBar->setValue(data->value("health").toInt());
+        if (healthBar->value()<healthBar->maximum()*0.3)
+            setBarStyle(healthBar, "eb0000");
+        else if (healthBar->value()>healthBar->maximum()*0.7)
+            setBarStyle(healthBar, "008000");
+        else
+            setBarStyle(healthBar, "f6f600");
+        questBar->setValue(data->value("quest_progress").toInt());
+        diaryLabel->setText(data->value("diary_last").toString());
+        energyLabel->setText(data->value("godpower").toString() + "%");
+        energyBar->setValue(data->value("godpower").toInt());
+        if (data->value("town_name").toString()=="")
         {
-            text = tr("%1 (%2 шт)").arg(text)
-              .arg(item.value("cnt").toInt());
-            n -= item.value("cnt").toInt()-1;
+            diLabel->setText(tr("Столбов от столицы"));
+            distanceLabel->setText(tr("%1 шт.")
+              .arg(data->value("distance").toString()));
+        }
+        else
+        {
+            diLabel->setText(tr("Город"));
+            distanceLabel->setText(data->value("town_name").toString());
         }
-        if (item.value("activate_by_user").toBool())
-            text = tr("%1 (@)").arg(text);
-        if (item.value("price").toInt())
-            text = "<b>" + text + "</b>";
-        if (item.value("type").toString()=="heal_potion")
-            text = "<i>" + text + "</i>";
-        text = "- " + text;
-        inventoryList[j]->setText(text);
-    }
-    while (inventoryList.size()>n)
-        delete inventoryList.takeLast();
-    if (n==0)
-        inventoryBox->setTitle(tr("В карманах пусто."));
-    else
-        inventoryBox->setTitle(tr("В карманах можно найти:"));
 
-    experienceBar->show();
-    inventoryBar->show();
-    healthBar->show();
-    questBar->show();
-    energyBox->show();
-    inventoryBox->show();
-    diaryBox->show();
-    diLabel->show();
-    distanceLabel->show();
+        QMap<QString, QVariant> inventory = data->value("inventory").toMap();
+        int n = data->value("inventory_num").toInt();
+        while (inventoryList.size()<n)
+        {
+            QLabel* lbl = new QLabel;
+            inventoryList.append(lbl);
+            inventoryVLayout->addWidget(lbl);
+            lbl->setWordWrap(true);
+        }
+        QMapIterator<QString, QVariant> i(inventory);
+        while (i.hasNext())
+        {
+            i.next();
+            QVariantMap item = i.value().toMap();
+            int j = item.value("pos").toInt();
+            QString text = i.key();
+            if (item.value("cnt").toInt()>1)
+            {
+                text = tr("%1 (%2 шт)").arg(text)
+                  .arg(item.value("cnt").toInt());
+                n -= item.value("cnt").toInt()-1;
+            }
+            if (item.value("activate_by_user").toBool())
+                text = tr("%1 (@)").arg(text);
+            if (item.value("price").toInt())
+                text = "<b>" + text + "</b>";
+            if (item.value("type").toString()=="heal_potion")
+                text = "<i>" + text + "</i>";
+            text = "- " + text;
+            inventoryList[j]->setText(text);
+        }
+        while (inventoryList.size()>n)
+            delete inventoryList.takeLast();
+        if (n==0)
+            inventoryBox->setTitle(tr("В карманах пусто."));
+        else
+            inventoryBox->setTitle(tr("В карманах можно найти:"));
+
+        experienceBar->show();
+        inventoryBar->show();
+        healthBar->show();
+        questBar->show();
+        energyBox->show();
+        inventoryBox->show();
+        diaryBox->show();
+        diLabel->show();
+        distanceLabel->show();
     }
     else
     {
@@ -403,20 +403,38 @@ void Godville::updateData()
 
 #ifdef Q_WS_MAEMO_5
     if (!expired and data->value("expired").toBool())
+    {
+        expired = data->value("expired").toBool();
         QMaemo5InformationBox::information(this, tr("Данные устарели!\nОткройте страницу героя через браузер или полноценный клиент."),
           QMaemo5InformationBox::NoTimeout);
+    }
+    else
+        expired = data->value("expired").toBool();
     if (!fight and data->value("arena_fight").toBool())
+    {
+        fight = data->value("arena_fight").toBool();
         QMaemo5InformationBox::information(this, tr("Битва началась!"),
           QMaemo5InformationBox::NoTimeout);
+    }
+    else
+        fight = data->value("arena_fight").toBool();
 #else
     if (!expired and data->value("expired").toBool())
+    {
+        expired = data->value("expired").toBool();
         QMessageBox::warning(this, tr("Данные устарели!"),
           tr("Откройте страницу героя через браузер или полноценный клиент."));
+    }
+    else
+        expired = data->value("expired").toBool();
     if (!fight and data->value("arena_fight").toBool())
+    {
+        fight = data->value("arena_fight").toBool();
         QMessageBox::warning(this, tr("Внимание!"), tr("Битва началась!"));
+    }
+    else
+        fight = data->value("arena_fight").toBool();
 #endif
-    expired = data->value("expired").toBool();
-    fight = data->value("arena_fight").toBool();
 }
 
 void Godville::forcedUpdate()
