@@ -1,4 +1,5 @@
 #include <QtGui>
+//#include <QDebug>
 #include "Godville.h"
 
 int main (int argc, char *argv[]) 
@@ -12,7 +13,7 @@ int main (int argc, char *argv[])
     QTranslator translator;
     if (settings.value("server").toString()=="godvillegame.com" or (!settings.contains("server") and QLocale::system().name()!="ru_RU"))
     {
-        translator.load("qgodville_en", "/usr/bin/qgodville");
+        translator.load("qgodville_en", "/usr/bin/qgodville/");
         app.installTranslator(&translator);
     }
 
